---
title: Spree 3.0.0
section: version
---

## Major/New Features

### Bootstrap Backend & Frontend

The most visible change will be the use of Bootstrap to replace the previous
Skeleton framework. We've redesigned the frontend, and backend while keeping
much of the previous structure to the site. We hope this will make upgrades
slightly easier to port to the new Bootstrap markup.  Now that we've updated
the default css/js framework we're hoping to begin implementing usability
improvements & improved mobile support.

### Rails 4.2 Support

We've added Rails 4.2 support laying the groundwork for further improvements.
Rails 4.2 comes with ActiveJob a background job API, which we will leverage in
the future to send long running tasks to Sidekiq, DelayedJob or Resque if you
set them up.  We've also already updated mailers to use the deliver later
functionality so your confirmation emails will be sent in the background.

### Google Analytics Enhanced Ecommerce

With the change to [enhanced ecommerce](https://developers.google.com/analytics/devguides/collection/analyticsjs/enhanced-ecommerce) tracking you should make sure to [upgrade your Google Analytics account to Universal Analytics](https://developers.google.com/analytics/devguides/collection/upgrade/reference/gajs-analyticsjs#overview).  If you use Spree's default google analytics implementation you should be fine, but if you've customized these make sure to update to [Universal Analytics](https://developers.google.com/analytics/devguides/collection/analyticsjs/).

## Upgrade Tips

### Read Rails 4.2 Release Notes & Upgrade Guide

[Release Notes](http://edgeguides.rubyonrails.org/4_2_release_notes.html)

[Upgrade Guide](http://edgeguides.rubyonrails.org/upgrading_ruby_on_rails.html#upgrading-from-rails-4-1-to-rails-4-2)

### Read Spree Upgrade Guide

For information about upgrading a basic spree store, please read the [2.4 to 3.0 upgrade guide](http://guides.spreecommerce.com/developer/upgrades/two-dot-four-to-three-dot-zero.html).

### Other Gotchas

Also please review each of the noteable changes, and ensure your customizations
or extensions are not effected. If you are effected by a change, and have any
of your own tips please submit a PR to help the next person!

SSLRequirement controller concern was removed in favor of using Rails built in [ForceSSL](http://api.rubyonrails.org/classes/ActionController/ForceSSL/ClassMethods.html).

If you were previously using ssl_required in any controllers you should now use force_ssl.

It is also recommended that you enable config.force_ssl = true within your production.rb file which will enforce SSL on every page.

## Full Changelog

You can view the full changes using [Github Compare](https://github.com/spree/spree/compare/2-4-stable...3-0-stable).

## Noteable Changes

* Switched to Bootstrap.

    Jeff Dutil & [Other Contributors](https://github.com/200Creative/spree_bootstrap_frontend/graphs/contributors)

* Moved Core's helpers into Frontend.

    Jeff Dutil

* Use Google Analytics Enhanced ecommerce.

    https://github.com/erikaxel

* PaymentMethod's and Tracker's are no longer based on environment.

    Clarke Brunsdon

* Removed promo code field from cart page. This prevents issues with promos
  attempting to be used before the order is ready. e.g. Free Shipping before shipments.

    Jeff Dutil

* Removed order token usage during guest checkout.

    https://github.com/spree/spree/pull/6072

* The line items order population endpoint used to accept a hash, it now accepts an array. When submitting a Post request to `/api/line_items` you will receive this deprecation warning:

  ```text
  Passing a hash is now deprecated and will be removed in Spree 3.1.
  It is recommended that you pass it as an array instead.

  New Syntax:

  {
    "order": {
      "line_items": [
        { "variant_id": 123, "quantity": 1 },
        { "variant_id": 456, "quantity": 1 }
      ]
    }
  }

  Old Syntax:

  {
    "order": {
      "line_items": {
        "1": { "variant_id": 123, "quantity": 1 },
        "2": { "variant_id": 123, "quantity": 1 }
      }
    }
  }
  ```

    Ben A. Morgan
